@@ -1810,202 +1810,3 @@ gpk_info_status_enum_to_icon_name (GpkInfoStatusEnum info)
 	/* regular PkInfoEnum */
 	return gpk_info_enum_to_icon_name (info);
 }
-
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-gpk_enum_test (gpointer data)
-{
-	guint i;
-	const gchar *string;
-	EggTest *test = (EggTest *) data;
-
-	if (!egg_test_start (test, "GpkEnum"))
-		return;
-
-	/************************************************************
-	 ****************     localized enums          **************
-	 ************************************************************/
-	egg_test_title (test, "check we convert all the localized past role enums");
-	for (i=0; i<PK_ROLE_ENUM_LAST; i++) {
-		string = gpk_role_enum_to_localised_past (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the localized present role enums");
-	for (i=0; i<PK_ROLE_ENUM_LAST; i++) {
-		string = gpk_role_enum_to_localised_present (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the role icon name enums");
-	for (i=PK_ROLE_ENUM_UNKNOWN+1; i<PK_ROLE_ENUM_LAST; i++) {
-		string = gpk_role_enum_to_icon_name (i);
-		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
-			egg_test_failed (test, "failed to get %s", pk_role_enum_to_string (i));
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the status animation enums");
-	for (i=PK_STATUS_ENUM_UNKNOWN+1; i<PK_STATUS_ENUM_UNKNOWN; i++) {
-		string = gpk_status_enum_to_animation (i);
-		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
-			egg_test_failed (test, "failed to get %s", pk_status_enum_to_string (i));
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the info icon names enums");
-	for (i=PK_INFO_ENUM_UNKNOWN+1; i<PK_INFO_ENUM_LAST; i++) {
-		string = gpk_info_enum_to_icon_name (i);
-		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
-			egg_test_failed (test, "failed to get %s", pk_info_enum_to_string (i));
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the localized status enums");
-	for (i=0; i<PK_STATUS_ENUM_LAST; i++) {
-		string = gpk_status_enum_to_localised_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the status icon names enums");
-	for (i=PK_STATUS_ENUM_UNKNOWN+1; i<PK_STATUS_ENUM_LAST; i++) {
-		string = gpk_status_enum_to_icon_name (i);
-		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
-			egg_test_failed (test, "failed to get %s", pk_status_enum_to_string (i));
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the restart icon names enums");
-	for (i=PK_RESTART_ENUM_UNKNOWN+1; i<PK_RESTART_ENUM_NONE; i++) {
-		string = gpk_restart_enum_to_icon_name (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %s", pk_restart_enum_to_string (i));
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the localized error enums");
-	for (i=0; i<PK_ERROR_ENUM_LAST; i++) {
-		string = gpk_error_enum_to_localised_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %s", pk_error_enum_to_string(i));
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the localized error messages");
-	for (i=0; i<PK_ERROR_ENUM_LAST; i++) {
-		string = gpk_error_enum_to_localised_message (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %s", pk_error_enum_to_string(i));
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the localized restart enums");
-	for (i=PK_RESTART_ENUM_UNKNOWN+1; i<PK_RESTART_ENUM_LAST; i++) {
-		string = gpk_restart_enum_to_localised_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the message icon name enums");
-	for (i=PK_MESSAGE_ENUM_UNKNOWN+1; i<PK_MESSAGE_ENUM_LAST; i++) {
-		string = gpk_message_enum_to_icon_name (i);
-		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
-			egg_test_failed (test, "failed to get %s", pk_message_enum_to_string (i));
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the localized message enums");
-	for (i=PK_MESSAGE_ENUM_UNKNOWN+1; i<PK_MESSAGE_ENUM_LAST; i++) {
-		string = gpk_message_enum_to_localised_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the localized restart future enums");
-	for (i=PK_RESTART_ENUM_UNKNOWN+1; i<PK_RESTART_ENUM_LAST; i++) {
-		string = gpk_restart_enum_to_localised_text_future (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the localized group enums");
-	for (i=0; i<PK_GROUP_ENUM_LAST; i++) {
-		string = gpk_group_enum_to_localised_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the group icon name enums");
-	for (i=PK_GROUP_ENUM_UNKNOWN+1; i<PK_GROUP_ENUM_LAST; i++) {
-		string = gpk_group_enum_to_icon_name (i);
-		if (string == NULL || g_strcmp0 (string, "help-browser") == 0) {
-			egg_test_failed (test, "failed to get %s", pk_group_enum_to_string (i));
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	egg_test_end (test);
-}
-#endif
-
